# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKOptimizersv4Python



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkExhaustiveOptimizerv4Python
else:
    import _itkExhaustiveOptimizerv4Python

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkArrayPython
import itk.itkObjectToObjectOptimizerBasePython
import itk.itkObjectToObjectMetricBasePython
import itk.itkSingleValuedCostFunctionv4Python
import itk.itkCostFunctionPython
import itk.itkOptimizerParametersPython
import itk.itkOptimizerParameterScalesEstimatorPython

def itkExhaustiveOptimizerv4D_New():
    return itkExhaustiveOptimizerv4D.New()

class itkExhaustiveOptimizerv4D(itk.itkObjectToObjectOptimizerBasePython.itkObjectToObjectOptimizerBaseTemplateD):
    r"""Proxy of C++ itkExhaustiveOptimizerv4D class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkExhaustiveOptimizerv4D_Pointer"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4D___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkExhaustiveOptimizerv4D_Pointer"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4D_Clone(self)

    def StartOptimization(self, doOnlyInitialization=False):
        r"""
        StartOptimization(self, doOnlyInitialization=False)

        Parameters
        ----------
        doOnlyInitialization: bool

        """
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4D_StartOptimization(self, doOnlyInitialization)

    def StartWalking(self):
        r"""StartWalking(self)"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4D_StartWalking(self)

    def ResumeWalking(self):
        r"""ResumeWalking(self)"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4D_ResumeWalking(self)

    def StopWalking(self):
        r"""StopWalking(self)"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4D_StopWalking(self)

    def SetStepLength(self, _arg):
        r"""
        SetStepLength(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4D_SetStepLength(self, _arg)

    def SetNumberOfSteps(self, _arg):
        r"""
        SetNumberOfSteps(self, _arg)

        Parameters
        ----------
        _arg: itkArrayUL

        """
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4D_SetNumberOfSteps(self, _arg)

    def GetStepLength(self):
        r"""GetStepLength(self) -> double const &"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4D_GetStepLength(self)

    def GetNumberOfSteps(self):
        r"""GetNumberOfSteps(self) -> itkArrayUL"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4D_GetNumberOfSteps(self)

    def GetCurrentValue(self):
        r"""GetCurrentValue(self) -> double const &"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4D_GetCurrentValue(self)

    def GetMaximumMetricValue(self):
        r"""GetMaximumMetricValue(self) -> double const &"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4D_GetMaximumMetricValue(self)

    def GetMinimumMetricValue(self):
        r"""GetMinimumMetricValue(self) -> double const &"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4D_GetMinimumMetricValue(self)

    def GetMinimumMetricValuePosition(self):
        r"""GetMinimumMetricValuePosition(self) -> itkOptimizerParametersD"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4D_GetMinimumMetricValuePosition(self)

    def GetMaximumMetricValuePosition(self):
        r"""GetMaximumMetricValuePosition(self) -> itkOptimizerParametersD"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4D_GetMaximumMetricValuePosition(self)

    def GetCurrentIndex(self):
        r"""GetCurrentIndex(self) -> itkOptimizerParametersD"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4D_GetCurrentIndex(self)

    def SetInitialPosition(self, param):
        r"""
        SetInitialPosition(self, param)

        Parameters
        ----------
        param: itkOptimizerParametersD const &

        """
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4D_SetInitialPosition(self, param)

    def GetInitialPosition(self):
        r"""GetInitialPosition(self) -> itkOptimizerParametersD"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4D_GetInitialPosition(self)
    __swig_destroy__ = _itkExhaustiveOptimizerv4Python.delete_itkExhaustiveOptimizerv4D

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkExhaustiveOptimizerv4D

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4D_cast(obj)

    def New(*args, **kargs):
        """New() -> itkExhaustiveOptimizerv4D

        Create a new object of the class itkExhaustiveOptimizerv4D and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkExhaustiveOptimizerv4D.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkExhaustiveOptimizerv4D.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkExhaustiveOptimizerv4D.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkExhaustiveOptimizerv4D in _itkExhaustiveOptimizerv4Python:
_itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4D_swigregister(itkExhaustiveOptimizerv4D)

def itkExhaustiveOptimizerv4F_New():
    return itkExhaustiveOptimizerv4F.New()

class itkExhaustiveOptimizerv4F(itk.itkObjectToObjectOptimizerBasePython.itkObjectToObjectOptimizerBaseTemplateF):
    r"""Proxy of C++ itkExhaustiveOptimizerv4F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkExhaustiveOptimizerv4F_Pointer"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4F___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkExhaustiveOptimizerv4F_Pointer"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4F_Clone(self)

    def StartOptimization(self, doOnlyInitialization=False):
        r"""
        StartOptimization(self, doOnlyInitialization=False)

        Parameters
        ----------
        doOnlyInitialization: bool

        """
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4F_StartOptimization(self, doOnlyInitialization)

    def StartWalking(self):
        r"""StartWalking(self)"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4F_StartWalking(self)

    def ResumeWalking(self):
        r"""ResumeWalking(self)"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4F_ResumeWalking(self)

    def StopWalking(self):
        r"""StopWalking(self)"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4F_StopWalking(self)

    def SetStepLength(self, _arg):
        r"""
        SetStepLength(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4F_SetStepLength(self, _arg)

    def SetNumberOfSteps(self, _arg):
        r"""
        SetNumberOfSteps(self, _arg)

        Parameters
        ----------
        _arg: itkArrayUL

        """
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4F_SetNumberOfSteps(self, _arg)

    def GetStepLength(self):
        r"""GetStepLength(self) -> double const &"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4F_GetStepLength(self)

    def GetNumberOfSteps(self):
        r"""GetNumberOfSteps(self) -> itkArrayUL"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4F_GetNumberOfSteps(self)

    def GetCurrentValue(self):
        r"""GetCurrentValue(self) -> float const &"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4F_GetCurrentValue(self)

    def GetMaximumMetricValue(self):
        r"""GetMaximumMetricValue(self) -> float const &"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4F_GetMaximumMetricValue(self)

    def GetMinimumMetricValue(self):
        r"""GetMinimumMetricValue(self) -> float const &"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4F_GetMinimumMetricValue(self)

    def GetMinimumMetricValuePosition(self):
        r"""GetMinimumMetricValuePosition(self) -> itkOptimizerParametersF"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4F_GetMinimumMetricValuePosition(self)

    def GetMaximumMetricValuePosition(self):
        r"""GetMaximumMetricValuePosition(self) -> itkOptimizerParametersF"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4F_GetMaximumMetricValuePosition(self)

    def GetCurrentIndex(self):
        r"""GetCurrentIndex(self) -> itkOptimizerParametersF"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4F_GetCurrentIndex(self)

    def SetInitialPosition(self, param):
        r"""
        SetInitialPosition(self, param)

        Parameters
        ----------
        param: itkOptimizerParametersF const &

        """
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4F_SetInitialPosition(self, param)

    def GetInitialPosition(self):
        r"""GetInitialPosition(self) -> itkOptimizerParametersF"""
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4F_GetInitialPosition(self)
    __swig_destroy__ = _itkExhaustiveOptimizerv4Python.delete_itkExhaustiveOptimizerv4F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkExhaustiveOptimizerv4F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4F_cast(obj)

    def New(*args, **kargs):
        """New() -> itkExhaustiveOptimizerv4F

        Create a new object of the class itkExhaustiveOptimizerv4F and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkExhaustiveOptimizerv4F.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkExhaustiveOptimizerv4F.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkExhaustiveOptimizerv4F.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkExhaustiveOptimizerv4F in _itkExhaustiveOptimizerv4Python:
_itkExhaustiveOptimizerv4Python.itkExhaustiveOptimizerv4F_swigregister(itkExhaustiveOptimizerv4F)

